@@ -143,7 +143,7 @@ def fixture_runner_result(
         ),
         pytest.param(
             "examples/playbooks/transform-no-free-form.yml",
-            3,
+            5,
             True,
             True,
             id="no_free_form_transform",
@@ -353,6 +353,8 @@ def test_pruned_err_after_fix(monkeypatch: pytest.MonkeyPatch, tmpdir: Path) ->
 
     monkeypatch.setattr("ansiblelint.__main__.fix", test_fix)
     monkeypatch.setattr("ansiblelint.app.App", TestApp)
+    # disable the App() caching because we cannot prevent the initial initialization from happening
+    monkeypatch.setattr("ansiblelint.app._CACHED_APP", None)
 
     main.main()
     assert fix_called
